@@ -45,6 +45,7 @@ getSample.mcmcSampler <- function(sampler, parametersOnly = T, coda = F, start =
     
     out = list()
     
+    
     for (i in 1:length(sampler$chain)){
       
       if(is.null(end)) end = nrow(sampler$chain[[1]])
@@ -78,6 +79,10 @@ getSample.mcmcSampler <- function(sampler, parametersOnly = T, coda = F, start =
       if(thin == 1 && !is.null(numSamples)){
         nSamplesPerChain <- ceiling(numSamples/length(sampler$chain))
         
+        if(i == 1){
+         if(nSamplesPerChain*length(sampler$chain) > numSamples) warning("Due to internal chains, numSamples was rounded to the next number divisble by the number of chains.", call. = FALSE)
+        }
+        
         temp <- sampleEquallySpaced(temp, nSamplesPerChain)
       }
       
